@@ -1,11 +1,14 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, ModelSQL, fields
-from trytond.pyson import Not, Bool, Eval
+from trytond.pyson import Eval
+from trytond.transaction import Transaction
+from trytond.pool import Pool
 
 STATES = {
-    'readonly': Not(Bool(Eval('active'))),
-}
+    'readonly': ~Eval('active', True),
+    }
+DEPENDS = ['active']
 
 
 class Template(ModelSQL, ModelView):
@@ -14,66 +17,63 @@ class Template(ModelSQL, ModelView):
     _description = __doc__
 
     name = fields.Char('Name', size=None, required=True, translate=True,
-            select=1, states=STATES)
+        select=1, states=STATES, depends=DEPENDS)
     type = fields.Selection([
-        ('stockable', 'Stockable'),
-        ('consumable', 'Consumable'),
-        ('service', 'Service')
-        ], 'Type', required=True, states=STATES)
-    category = fields.Many2One('product.category','Category', required=True,
-            states=STATES)
+            ('stockable', 'Stockable'),
+            ('consumable', 'Consumable'),
+            ('service', 'Service')
+            ], 'Type', required=True, states=STATES, depends=DEPENDS)
+    category = fields.Many2One('product.category', 'Category', required=True,
+        states=STATES, depends=DEPENDS)
     list_price = fields.Property(fields.Numeric('List Price', states=STATES,
-        digits=(16, 4)))
+            digits=(16, 4), depends=DEPENDS))
     list_price_uom = fields.Function(fields.Numeric('List Price',
         digits=(16, 4)), 'get_price_uom')
     cost_price = fields.Property(fields.Numeric('Cost Price',
-            states=STATES, digits=(16, 4)))
+            states=STATES, digits=(16, 4), depends=DEPENDS))
     cost_price_uom = fields.Function(fields.Numeric('Cost Price',
         digits=(16, 4)), 'get_price_uom')
     cost_price_method = fields.Property(fields.Selection([
-        ("fixed", "Fixed"),
-        ("average", "Average")
-        ], 'Cost Method', required=True, states=STATES))
+                ("fixed", "Fixed"),
+                ("average", "Average")
+                ], 'Cost Method', required=True, states=STATES,
+            depends=DEPENDS))
     default_uom = fields.Many2One('product.uom', 'Default UOM', required=True,
-            states=STATES)
+        states=STATES, depends=DEPENDS)
     active = fields.Boolean('Active', select=1)
     products = fields.One2Many('product.product', 'template', 'Products',
-            states=STATES)
+        states=STATES, depends=DEPENDS)
 
-    def default_active(self, cursor, user, context=None):
+    def default_active(self):
         return True
 
-    def default_type(self, cursor, user, context=None):
+    def default_type(self):
         return 'stockable'
 
-    def default_cost_price_method(self, cursor, user, context=None):
+    def default_cost_price_method(self):
         return 'fixed'
 
-    def get_price_uom(self, cursor, user, ids, name, context=None):
-        product_uom_obj = self.pool.get('product.uom')
+    def get_price_uom(self, ids, name):
+        product_uom_obj = Pool().get('product.uom')
         res = {}
-        if context is None:
-            context = {}
         field = name[:-4]
-        if context.get('uom'):
-            to_uom = self.pool.get('product.uom').browse(
-                cursor, user, context['uom'], context=context)
-            for product in self.browse(cursor, user, ids, context=context):
+        if Transaction().context.get('uom'):
+            to_uom = product_uom_obj.browse(
+                Transaction().context['uom'])
+            for product in self.browse(ids):
                 res[product.id] = product_uom_obj.compute_price(
-                        cursor, user, product.default_uom, product[field],
-                        to_uom, context=context)
+                        product.default_uom, product[field], to_uom)
         else:
-            for product in self.browse(cursor, user, ids, context=context):
+            for product in self.browse(ids):
                 res[product.id] = product[field]
         return res
 
-    def copy(self, cursor, user, ids, default=None, context=None):
+    def copy(self, ids, default=None):
         if default is None:
             default = {}
         default = default.copy()
         default['products'] = False
-        return super(Template, self).copy(cursor, user, ids, default=default,
-                context=context)
+        return super(Template, self).copy(ids, default=default)
 
 Template()
 
@@ -89,51 +89,47 @@ class Product(ModelSQL, ModelView):
     code = fields.Char("Code", size=None, select=1)
     description = fields.Text("Description", translate=True)
 
-    def get_rec_name(self, cursor, user, ids, name, context=None):
+    def get_rec_name(self, ids, name):
         if not ids:
             return {}
         res = {}
-        for product in self.browse(cursor, user, ids, context=context):
+        for product in self.browse(ids):
             name = product.name
             if product.code:
                 name = '[' + product.code + '] ' + product.name
             res[product.id] = name
         return res
 
-    def search_rec_name(self, cursor, user, name, clause, context=None):
-        ids = self.search(cursor, user, [('code',) + clause[1:]],
-                order=[], context=context)
+    def search_rec_name(self, name, clause):
+        ids = self.search([('code',) + clause[1:]], order=[])
         if ids:
-            ids += self.search(cursor, user, [('name',) + clause[1:]],
-                    order=[], context=context)
+            ids += self.search([('name',) + clause[1:]], order=[])
             return [('id', 'in', ids)]
         return [('name',) + clause[1:]]
 
-    def delete(self, cursor, user, ids, context=None):
-        template_obj = self.pool.get('product.template')
+    def delete(self, ids):
+        template_obj = Pool().get('product.template')
 
         if isinstance(ids, (int, long)):
             ids = [ids]
 
         # Get the templates before we delete the products.
-        products = self.browse(cursor, user, ids, context=context)
+        products = self.browse(ids)
         template_ids = [product.template.id for product in products]
 
-        res = super(Product, self).delete(cursor, user, ids, context=context)
+        res = super(Product, self).delete(ids)
 
         # Get templates that are still linked after delete.
-        templates = template_obj.browse(cursor, user, template_ids,
-                                        context=context)
+        templates = template_obj.browse(template_ids)
         unlinked_template_ids = [template.id for template in templates \
                                  if not template.products]
         if unlinked_template_ids:
-            template_obj.delete(cursor, user, unlinked_template_ids,
-                                context=context)
+            template_obj.delete(unlinked_template_ids)
 
         return res
 
-    def copy(self, cursor, user, ids, default=None, context=None):
-        template_obj = self.pool.get('product.template')
+    def copy(self, ids, default=None):
+        template_obj = Pool().get('product.template')
 
         int_id = False
         if isinstance(ids, (int, long)):
@@ -144,11 +140,9 @@ class Product(ModelSQL, ModelView):
         default = default.copy()
         default['products'] = False
         new_ids = []
-        for product in self.browse(cursor, user, ids, context=context):
-            default['template'] = template_obj.copy(cursor, user,
-                    product.template.id, context=context)
-            new_id = super(Product, self).copy(cursor, user, product.id,
-                default=default, context=context)
+        for product in self.browse(ids):
+            default['template'] = template_obj.copy(product.template.id)
+            new_id = super(Product, self).copy(product.id, default=default)
             new_ids.append(new_id)
 
         if int_id:
